@@ -572,11 +572,15 @@ ext2fs_file_walk_direct(FS_INFO *fs, FS_BUF *buf[],
     	read_count = (length < buf[0]->size ? length : buf[0]->size);
 
 	if (addr > fs->last_block) {
-		if (flags & FS_FLAG_NOABORT) 
+		if (flags & FS_FLAG_NOABORT)  {
+			fprintf (stderr, "Invalid direct block address (too large): %lu",
+		  	  (ULONG) addr);
 			return 0;
-		else
+		}
+		else {
 			error ("Invalid direct block address (too large): %lu",
 		  	  (ULONG) addr);
+		}
 	}
 
 	myflags = FS_FLAG_CONT;
@@ -622,11 +626,15 @@ ext2fs_file_walk_indir(FS_INFO *fs, FS_BUF *buf[], OFF_T length,
     	fprintf(logfp, "%s: level %d block %lu\n", myname, level, (ULONG) addr);
     
     if (addr > fs->last_block) {
-        if (flags & FS_FLAG_NOABORT) 
+        if (flags & FS_FLAG_NOABORT)  {
+        	fprintf (stderr, "Invalid indirect block address (too large): %lu",
+			  (ULONG)addr);
             return 0;    
-		else
+		}
+		else {
         	error ("Invalid indirect block address (too large): %lu",
 			  (ULONG)addr);
+		}
     } 
 
     /*
@@ -652,11 +660,15 @@ ext2fs_file_walk_indir(FS_INFO *fs, FS_BUF *buf[], OFF_T length,
 		int prevcnt = todo_count;
 
 	    if (getu32(fs, (u_int8_t *)&iaddr[n]) > fs->last_block) {
-			if (flags & FS_FLAG_NOABORT) 
+			if (flags & FS_FLAG_NOABORT)  {
+				fprintf (stderr, "Invalid address in indirect list (too large): %lu",
+          		  (ULONG)getu32(fs, (u_int8_t *)&iaddr[n]) );
 				return 0;    
-			else
+			}
+			else {
 				error ("Invalid address in indirect list (too large): %lu",
           		  (ULONG)getu32(fs, (u_int8_t *)&iaddr[n]) );
+			}
 		}
 
 
